//
//  View.swift
//  Swipe
//
//  Created by Mark Meretzky on 7/16/16.
//  Copyright © 2016 Mark Meretzky. All rights reserved.
//

import UIKit;

class View: UITextView {

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;
		
		editable = false;	//Don't pop up a keyboard when touched.
		font = UIFont.systemFontOfSize(16);
		text = "\nPlease swipe your finger."
		
		//Selector swipe(_:) has one colon because it takes one parameter,
		//underscore because te parameter takes no external parameter name.
		
		let rightRecognizer: UISwipeGestureRecognizer =
			UISwipeGestureRecognizer(target: self, action: #selector(View.swipe(_:)));
		rightRecognizer.direction = UISwipeGestureRecognizerDirection.Right;
		addGestureRecognizer(rightRecognizer);
		
		let leftRecognizer: UISwipeGestureRecognizer =
			UISwipeGestureRecognizer(target: self, action: #selector(View.swipe(_:)));
		leftRecognizer.direction = UISwipeGestureRecognizerDirection.Left;
		addGestureRecognizer(leftRecognizer);
		
		let upRecognizer: UISwipeGestureRecognizer =
			UISwipeGestureRecognizer(target: self, action: #selector(View.swipe(_:)));
		upRecognizer.direction = UISwipeGestureRecognizerDirection.Up;
		addGestureRecognizer(upRecognizer);
		
		let downRecognizer: UISwipeGestureRecognizer =
			UISwipeGestureRecognizer(target: self, action: #selector(View.swipe(_:)));
		downRecognizer.direction = UISwipeGestureRecognizerDirection.Down;
		addGestureRecognizer(downRecognizer);
	}
	
	func swipe(recognizer: UISwipeGestureRecognizer) -> Void {
		let p: CGPoint = recognizer.locationInView(self);
		let direction: String;
		
		if recognizer.direction == UISwipeGestureRecognizerDirection.Right {
			direction = "→";
		} else if recognizer.direction == UISwipeGestureRecognizerDirection.Left {
			direction = "←";
		} else if recognizer.direction == UISwipeGestureRecognizerDirection.Up {
			direction = "↑";
		} else if recognizer.direction == UISwipeGestureRecognizerDirection.Down {
			direction = "↓";
		} else {
			direction = "unknown";
		}
		
		text =
			"\n" +
			"direction: \(direction)\n" +
			"start: \(p)\n" +
			"number of touches: \(recognizer.numberOfTouches())\n" +
			"number of touches required: \(recognizer.numberOfTouchesRequired)\n\n";
		
		//Print each individual finger.
		for i in 0 ..< recognizer.numberOfTouches() {
			let p: CGPoint = recognizer.locationOfTouch(i, inView: self);
			text = text + "touch \(i) start: \(p))\n";
		}
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
